aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-05-21 19:50:49 +0200
committerMattias Andrée <maandree@operamail.com>2014-05-21 19:50:49 +0200
commitf4f7b4579b72cb5c08188ba4edcfa07ae57a3542 (patch)
treee8c02434997b0e9236c3fec367252f9c7928d34f
parentadd ./configure (diff)
downloadlibgamma-f4f7b4579b72cb5c08188ba4edcfa07ae57a3542.tar.gz
libgamma-f4f7b4579b72cb5c08188ba4edcfa07ae57a3542.tar.bz2
libgamma-f4f7b4579b72cb5c08188ba4edcfa07ae57a3542.tar.xz
misc
Signed-off-by: Mattias Andrée <maandree@operamail.com>
-rw-r--r--.gitignore1
-rw-r--r--COPYING1
-rw-r--r--Makefile2
-rwxr-xr-xconfigure27
-rw-r--r--src/gamma-x-randr.c (renamed from src/gamma-vidmode.c)52
-rw-r--r--src/gamma-x-randr.h (renamed from src/gamma-vidmode.h)54
-rw-r--r--src/gamma-x-vidmode.c (renamed from src/gamma-randr.c)80
-rw-r--r--src/gamma-x-vidmode.h (renamed from src/gamma-randr.h)82
-rw-r--r--src/libgamma-error.h4
-rw-r--r--src/libgamma-facade.c100
-rw-r--r--src/libgamma-facade.h4
-rw-r--r--src/libgamma-method.h4
-rw-r--r--src/libgamma.h2
13 files changed, 225 insertions, 188 deletions
diff --git a/.gitignore b/.gitignore
index bf0de41..fd77d0b 100644
--- a/.gitignore
+++ b/.gitignore
@@ -13,4 +13,5 @@ obj/
*.out
*.o
/config.mk
+/src/libgamma-config.h
diff --git a/COPYING b/COPYING
index bd29ce9..1a52d02 100644
--- a/COPYING
+++ b/COPYING
@@ -13,4 +13,3 @@ GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this library. If not, see <http://www.gnu.org/licenses/>.
-
diff --git a/Makefile b/Makefile
index 5e435ad..ae4ad31 100644
--- a/Makefile
+++ b/Makefile
@@ -88,5 +88,5 @@ obj/%.o: src/%.c src/*.h
.PHONY: clean
clean:
- -rm -rf obj bin
+ -rm -rf obj bin config.mk
diff --git a/configure b/configure
index 86e85b6..e3683a3 100755
--- a/configure
+++ b/configure
@@ -79,8 +79,17 @@ done
exec 3> "$(dirname "$0")/config.mk"
+exec 4> "$(dirname "$0")/src/libgamma-config.h"
echo 'DEFINITIONS =' >&3
+echo '/**' >&4
+cat "$(dirname "$0")/COPYING" | sed -e 's:^: \* :' >&4
+echo ' */' >&4
+echo '#ifndef LIBGAMMA_CONFIG_H' >&4
+echo '#define LIBGAMMA_CONFIG_H' >&4
+echo >&4
+echo >&4
+
if [ ${fake_w32gdi} = 1 ]; then
enable_w32gdi=1
fi
@@ -93,30 +102,37 @@ if [ ${enable_debug} = 1 ]; then
fi
if [ ${enable_dummy} = 1 ]; then
echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_DUMMY' >&3
+ echo '#define HAVE_GAMMA_METHOD_DUMMY' >&4
have_dummy='Yes'
fi
if [ ${enable_randr} = 1 ]; then
- echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_RANDR' >&3
+ echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_X_RANDR' >&3
+ echo '#define HAVE_GAMMA_METHOD_X_RANDR' >&4
have_randr='Yes'
fi
if [ ${enable_vidmode} = 1 ]; then
- echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_VIDMODE' >&3
+ echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_X_VIDMODE' >&3
+ echo '#define HAVE_GAMMA_METHOD_X_VIDMODE' >&4
have_vidmode='Yes'
fi
if [ ${enable_drm} = 1 ]; then
echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_LINUX_DRM' >&3
+ echo '#define HAVE_GAMMA_METHOD_LINUX_DRM' >&4
have_drm='Yes'
fi
if [ ${enable_w32gdi} = 1 ]; then
echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_W32_GDI' >&3
+ echo '#define HAVE_GAMMA_METHOD_W32_GDI' >&4
have_w32gdi='Yes'
fi
if [ ${enable_quartz} = 1 ]; then
echo 'DEFINITIONS += -DHAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS' >&3
+ echo '#define HAVE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS' >&4
have_quartz='Yes'
fi
if [ ${fake_w32gdi} = 1 ]; then
echo 'DEFINITIONS += -FAKE_GAMMA_METHOD_W32_GDI' >&3
+ echo '#define FAKE_GAMMA_METHOD_W32_GDI' >&4
if [ ${enable_randr} = 1 ]; then
have_w32gdi='Yes, fake via the RandR protocol for X'
else
@@ -125,6 +141,7 @@ if [ ${fake_w32gdi} = 1 ]; then
fi
if [ ${fake_quartz} = 1 ]; then
echo 'DEFINITIONS += -FAKE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS' >&3
+ echo '#define FAKE_GAMMA_METHOD_QUARTZ_CORE_GRAPHICS' >&4
if [ ${enable_randr} = 1 ]; then
have_quartz='Yes, fake via the RandR protocol for X'
else
@@ -132,6 +149,12 @@ if [ ${fake_quartz} = 1 ]; then
fi
fi
+echo >&4
+echo >&4
+echo '#endif' >&4
+echo >&4
+
+exec 4<&-
exec 3<&-
diff --git a/src/libgamma-error.h b/src/libgamma-error.h
index f506955..d17eac8 100644
--- a/src/libgamma-error.h
+++ b/src/libgamma-error.h
@@ -18,6 +18,10 @@
#ifndef LIBGAMMA_ERROR_H
#define LIBGAMMA_ERROR_H
+#if !defined(LIBGAMMA_CONFIG_H) && !defined(DEBUG)
+# error libgamma-error.h should not be included directly, include libgamma.h instead
+#endif
+
/**
* The selected adjustment method does not exist
diff --git a/src/libgamma-facade.c b/src/libgamma-facade.c
index 5111a07..7736118 100644
--- a/src/libgamma-facade.c
+++ b/src/libgamma-facade.c
@@ -26,13 +26,13 @@
# endif
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
-# include "gamma-randr.h"
+# include "gamma-x-randr.h"
# ifndef HAVE_GAMMA_METHODS
# define HAVE_GAMMA_METHODS
# endif
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
-# include "gamma-vidmode.h"
+# include "gamma-x-vidmode.h"
# ifndef HAVE_GAMMA_METHODS
# define HAVE_GAMMA_METHODS
# endif
@@ -176,13 +176,13 @@ size_t libgamma_list_methods(int* methods, int operation)
#else
size_t n = 0;
-#ifdef HAVE_GAMMA_METHOD_RANDR
- if (libgamma_list_method_test(GAMMA_METHOD_RANDR, operation))
- methods[n++] = GAMMA_METHOD_RANDR;
+#ifdef HAVE_GAMMA_METHOD_X_RANDR
+ if (libgamma_list_method_test(GAMMA_METHOD_X_RANDR, operation))
+ methods[n++] = GAMMA_METHOD_X_RANDR;
#endif
-#ifdef HAVE_GAMMA_METHOD_VIDMODE
- if (libgamma_list_method_test(GAMMA_METHOD_VIDMODE, operation))
- methods[n++] = GAMMA_METHOD_VIDMODE;
+#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
+ if (libgamma_list_method_test(GAMMA_METHOD_X_VIDMODE, operation))
+ methods[n++] = GAMMA_METHOD_X_VIDMODE;
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
if (libgamma_list_method_test(GAMMA_METHOD_LINUX_DRM, operation))
@@ -225,12 +225,12 @@ void libgamma_method_capabilities(libgamma_method_capabilities_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- libgamma_randr_method_capabilities(this);
+ libgamma_x_randr_method_capabilities(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- libgamma_vidmode_method_capabilities(this);
+ libgamma_x_vidmode_method_capabilities(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
@@ -339,11 +339,11 @@ int libgamma_site_initialise(libgamma_site_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_site_initialise(this, site);
+ return libgamma_x_randr_site_initialise(this, site);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_site_initialise(this, site);
+ return libgamma_x_vidmode_site_initialise(this, site);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -380,12 +380,12 @@ void libgamma_site_destroy(libgamma_site_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- libgamma_randr_site_destroy(this);
+ libgamma_x_randr_site_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- libgamma_vidmode_site_destroy(this);
+ libgamma_x_vidmode_site_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
@@ -443,11 +443,11 @@ int libgamma_site_restore(libgamma_site_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_site_restore(this);
+ return libgamma_x_randr_site_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_site_restore(this);
+ return libgamma_x_vidmode_site_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -492,11 +492,11 @@ int libgamma_partition_initialise(libgamma_partition_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_partition_initialise(this, site, partition);
+ return libgamma_x_randr_partition_initialise(this, site, partition);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_partition_initialise(this, site, partition);
+ return libgamma_x_vidmode_partition_initialise(this, site, partition);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -533,12 +533,12 @@ void libgamma_partition_destroy(libgamma_partition_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- libgamma_randr_partition_destroy(this);
+ libgamma_x_randr_partition_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- libgamma_vidmode_partition_destroy(this);
+ libgamma_x_vidmode_partition_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
@@ -595,11 +595,11 @@ int libgamma_partition_restore(libgamma_partition_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_partition_restore(this);
+ return libgamma_x_randr_partition_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_partition_restore(this);
+ return libgamma_x_vidmode_partition_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -644,11 +644,11 @@ int libgamma_crtc_initialise(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_initialise(this, partition, crtc);
+ return libgamma_x_randr_crtc_initialise(this, partition, crtc);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_initialise(this, partition, crtc);
+ return libgamma_x_vidmode_crtc_initialise(this, partition, crtc);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -685,12 +685,12 @@ void libgamma_crtc_destroy(libgamma_crtc_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- libgamma_randr_crtc_destroy(this);
+ libgamma_x_randr_crtc_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- libgamma_vidmode_crtc_destroy(this);
+ libgamma_x_vidmode_crtc_destroy(this);
break;
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
@@ -747,11 +747,11 @@ int libgamma_crtc_restore(libgamma_crtc_state_t* restrict this)
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_restore(this);
+ return libgamma_x_randr_crtc_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_restore(this);
+ return libgamma_x_vidmode_crtc_restore(this);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -797,11 +797,11 @@ int libgamma_get_crtc_information(libgamma_crtc_information_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_get_crtc_information(this, crtc, fields);
+ return libgamma_x_randr_get_crtc_information(this, crtc, fields);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_get_crtc_information(this, crtc, fields);
+ return libgamma_x_vidmode_get_crtc_information(this, crtc, fields);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -973,11 +973,11 @@ int libgamma_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_get_gamma_ramps(this, ramps);
+ return libgamma_x_randr_crtc_get_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_get_gamma_ramps(this, ramps);
+ return libgamma_x_vidmode_crtc_get_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1021,11 +1021,11 @@ int libgamma_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_set_gamma_ramps(this, ramps);
+ return libgamma_x_randr_crtc_set_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_set_gamma_ramps(this, ramps);
+ return libgamma_x_vidmode_crtc_set_gamma_ramps(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1070,11 +1070,11 @@ int libgamma_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_get_gamma_ramps32(this, ramps);
+ return libgamma_x_randr_crtc_get_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_get_gamma_ramps32(this, ramps);
+ return libgamma_x_vidmode_crtc_get_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1118,11 +1118,11 @@ int libgamma_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_set_gamma_ramps32(this, ramps);
+ return libgamma_x_randr_crtc_set_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_set_gamma_ramps32(this, ramps);
+ return libgamma_x_vidmode_crtc_set_gamma_ramps32(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1167,11 +1167,11 @@ int libgamma_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_get_gamma_ramps64(this, ramps);
+ return libgamma_x_randr_crtc_get_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_get_gamma_ramps64(this, ramps);
+ return libgamma_x_vidmode_crtc_get_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1215,11 +1215,11 @@ int libgamma_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_set_gamma_ramps64(this, ramps);
+ return libgamma_x_randr_crtc_set_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_set_gamma_ramps64(this, ramps);
+ return libgamma_x_vidmode_crtc_set_gamma_ramps64(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1264,11 +1264,11 @@ int libgamma_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_get_gamma_rampsf(this, ramps);
+ return libgamma_x_randr_crtc_get_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_get_gamma_rampsf(this, ramps);
+ return libgamma_x_vidmode_crtc_get_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1312,11 +1312,11 @@ int libgamma_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_set_gamma_rampsf(this, ramps);
+ return libgamma_x_randr_crtc_set_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_set_gamma_rampsf(this, ramps);
+ return libgamma_x_vidmode_crtc_set_gamma_rampsf(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1361,11 +1361,11 @@ int libgamma_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_get_gamma_rampsd(this, ramps);
+ return libgamma_x_randr_crtc_get_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_get_gamma_rampsd(this, ramps);
+ return libgamma_x_vidmode_crtc_get_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
@@ -1409,11 +1409,11 @@ int libgamma_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
#endif
#ifdef HAVE_GAMMA_METHOD_X_RANDR
case GAMMA_METHOD_X_RANDR:
- return libgamma_randr_crtc_set_gamma_rampsd(this, ramps);
+ return libgamma_x_randr_crtc_set_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_X_VIDMODE
case GAMMA_METHOD_X_VIDMODE:
- return libgamma_vidmode_crtc_set_gamma_rampsd(this, ramps);
+ return libgamma_x_vidmode_crtc_set_gamma_rampsd(this, ramps);
#endif
#ifdef HAVE_GAMMA_METHOD_LINUX_DRM
case GAMMA_METHOD_LINUX_DRM:
diff --git a/src/libgamma-facade.h b/src/libgamma-facade.h
index 19581a0..d4399b3 100644
--- a/src/libgamma-facade.h
+++ b/src/libgamma-facade.h
@@ -18,6 +18,10 @@
#ifndef LIBGAMMA_FACADE_H
#define LIBGAMMA_FACADE_H
+#if !defined(LIBGAMMA_CONFIG_H) && !defined(DEBUG)
+# error libgamma-facade.h should not be included directly, include libgamma.h instead
+#endif
+
#include "libgamma-method.h"
diff --git a/src/libgamma-method.h b/src/libgamma-method.h
index e79e893..3fac0da 100644
--- a/src/libgamma-method.h
+++ b/src/libgamma-method.h
@@ -18,6 +18,10 @@
#ifndef LIBGAMMA_METHOD_H
#define LIBGAMMA_METHOD_H
+#if !defined(LIBGAMMA_CONFIG_H) && !defined(DEBUG)
+# error libgamma-method.h should not be included directly, include libgamma.h instead
+#endif
+
#include <stddef.h>
#include <stdint.h>
diff --git a/src/libgamma.h b/src/libgamma.h
index d6b727c..9a5b9be 100644
--- a/src/libgamma.h
+++ b/src/libgamma.h
@@ -19,6 +19,8 @@
#define LIBGAMMA_H
+#include "libgamma-config.h" /* Must be first. */
+
#include "libgamma-method.h"
#include "libgamma-facade.h"
#include "libgamma-error.h"
diff --git a/src/gamma-vidmode.c b/src/gamma-x-randr.c
index ae74ac2..9426756 100644
--- a/src/gamma-vidmode.c
+++ b/src/gamma-x-randr.c
@@ -15,11 +15,11 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef HAVE_GAMMA_METHOD_VIDMODE
# error Compiling gamma-vidmode.c without HAVE_GAMMA_METHOD_VIDMODE
#endif
-#include "gamma-vidmode.h"
+#include "gamma-x-randr.h"
#include "gamma-error.h"
@@ -29,7 +29,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this)
+void libgamma_x_randr_method_capabilities(libgamma_method_capabilities_t* restrict this)
{
}
@@ -47,7 +47,7 @@ void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restri
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+int libgamma_x_randr_site_initialise(libgamma_site_state_t* restrict this,
char* restrict site)
{
}
@@ -58,7 +58,7 @@ int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
*
* @param this The site state
*/
-void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this)
+void libgamma_x_randr_site_destroy(libgamma_site_state_t* restrict this)
{
}
@@ -70,7 +70,7 @@ void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this)
+int libgamma_x_randr_site_restore(libgamma_site_state_t* restrict this)
{
}
@@ -85,7 +85,7 @@ int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+int libgamma_x_randr_partition_initialise(libgamma_partition_state_t* restrict this,
libgamma_site_state_t* restrict site, size_t partition)
{
}
@@ -96,7 +96,7 @@ int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict t
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict this)
+void libgamma_x_randr_partition_destroy(libgamma_partition_state_t* restrict this)
{
}
@@ -107,7 +107,7 @@ void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict thi
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this)
+void libgamma_x_randr_partition_free(libgamma_partition_state_t* restrict this)
{
}
@@ -119,7 +119,7 @@ void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this)
+int libgamma_x_randr_partition_restore(libgamma_partition_state_t* restrict this)
{
}
@@ -134,7 +134,7 @@ int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
libgamma_partition_state_t* restrict partition, size_t crtc)
{
}
@@ -145,7 +145,7 @@ int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this)
+void libgamma_x_randr_crtc_destroy(libgamma_crtc_state_t* restrict this)
{
}
@@ -156,7 +156,7 @@ void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this)
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this)
+void libgamma_x_randr_crtc_free(libgamma_crtc_state_t* restrict this)
{
}
@@ -168,7 +168,7 @@ void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this)
+int libgamma_x_randr_crtc_restore(libgamma_crtc_state_t* restrict this)
{
}
@@ -182,7 +182,7 @@ int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this)
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+int libgamma_x_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
libgamma_crtc_state_t* restrict crtc, int32_t fields)
{
}
@@ -196,7 +196,7 @@ int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t* restrict ramps)
{
}
@@ -210,7 +210,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t ramps)
{
}
@@ -225,7 +225,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t* restrict ramps)
{
}
@@ -239,7 +239,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t ramps)
{
}
@@ -254,7 +254,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t* restrict ramps)
{
}
@@ -268,7 +268,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t ramps)
{
}
@@ -283,7 +283,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t* restrict ramps)
{
}
@@ -297,7 +297,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t ramps)
{
}
@@ -311,7 +311,7 @@ int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t* restrict ramps)
{
}
@@ -325,7 +325,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t ramps)
{
}
@@ -15,11 +15,11 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef HAVE_GAMMA_METHOD_VIDMODE
-# error Compiling gamma-vidmode.c without HAVE_GAMMA_METHOD_VIDMODE
+#ifndef HAVE_GAMMA_METHOD_X_RANDR
+# error Compiling gamma-x-randr.c without HAVE_GAMMA_METHOD_X_RANDR
#endif
diff --git a/src/gamma-vidmode.h b/src/gamma-x-randr.h
index 5b38798..cc4ddde 100644
--- a/src/gamma-vidmode.h
+++ b/src/gamma-x-randr.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LIBGAMMA_GAMMA_VIDMODE_H
#define LIBGAMMA_GAMMA_VIDMODE_H
#ifndef HAVE_GAMMA_METHOD_VIDMODE
# error Including gamma-vidmode.h without HAVE_GAMMA_METHOD_VIDMODE
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_x_randr_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,7 +47,7 @@ void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restri
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+int libgamma_x_randr_site_initialise(libgamma_site_state_t* restrict this,
char* restrict site);
/**
@@ -55,7 +55,7 @@ int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
*
* @param this The site state
*/
-void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_x_randr_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_x_randr_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,7 +76,7 @@ int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+int libgamma_x_randr_partition_initialise(libgamma_partition_state_t* restrict this,
libgamma_site_state_t* restrict site, size_t partition);
/**
@@ -84,7 +84,7 @@ int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict t
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_x_randr_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict thi
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_x_randr_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_x_randr_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,7 +113,7 @@ int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
libgamma_partition_state_t* restrict partition, size_t crtc);
/**
@@ -121,7 +121,7 @@ int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_x_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_x_randr_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_x_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,7 +149,7 @@ int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+int libgamma_x_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
@@ -160,7 +160,7 @@ int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t* restrict ramps);
/**
@@ -171,7 +171,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t ramps);
@@ -183,7 +183,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t* restrict ramps);
/**
@@ -194,7 +194,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t ramps);
@@ -206,7 +206,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t* restrict ramps);
/**
@@ -217,7 +217,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t ramps);
@@ -229,7 +229,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t* restrict ramps);
/**
@@ -240,7 +240,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t ramps);
/**
@@ -251,7 +251,7 @@ int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t* restrict ramps);
/**
@@ -262,7 +262,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t ramps);
@@ -15,12 +15,12 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_VIDMODE_H
-#define LIBGAMMA_GAMMA_VIDMODE_H
+#ifndef LIBGAMMA_GAMMA_X_RANDR_H
+#define LIBGAMMA_GAMMA_X_RANDR_H
-#ifndef HAVE_GAMMA_METHOD_VIDMODE
-# error Including gamma-vidmode.h without HAVE_GAMMA_METHOD_VIDMODE
+#ifndef HAVE_GAMMA_METHOD_X_RANDR
+# error Including gamma-x-randr.h without HAVE_GAMMA_METHOD_X_RANDR
#endif
diff --git a/src/gamma-randr.c b/src/gamma-x-vidmode.c
index cab1385..c1df905 100644
--- a/src/gamma-randr.c
+++ b/src/gamma-x-vidmode.c
@@ -15,11 +15,11 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef HAVE_GAMMA_METHOD_RANDR
# error Compiling gamma-randr.c without HAVE_GAMMA_METHOD_RANDR
#endif
-#include "gamma-randr.h"
+#include "gamma-x-vidmode.h"
#include "gamma-error.h"
@@ -29,7 +29,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict this)
+void libgamma_x_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this)
{
}
@@ -47,8 +47,8 @@ void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_initialise(libgamma_site_state_t* restrict this,
- char* restrict site)
+int libgamma_x_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+ char* restrict site)
{
}
@@ -58,7 +58,7 @@ int libgamma_randr_site_initialise(libgamma_site_state_t* restrict this,
*
* @param this The site state
*/
-void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this)
+void libgamma_x_vidmode_site_destroy(libgamma_site_state_t* restrict this)
{
}
@@ -70,7 +70,7 @@ void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_restore(libgamma_site_state_t* restrict this)
+int libgamma_x_vidmode_site_restore(libgamma_site_state_t* restrict this)
{
}
@@ -85,8 +85,8 @@ int libgamma_randr_site_restore(libgamma_site_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_initialise(libgamma_partition_state_t* restrict this,
- libgamma_site_state_t* restrict site, size_t partition)
+int libgamma_x_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+ libgamma_site_state_t* restrict site, size_t partition)
{
}
@@ -96,7 +96,7 @@ int libgamma_randr_partition_initialise(libgamma_partition_state_t* restrict thi
*
* @param this The partition state
*/
-void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this)
+void libgamma_x_vidmode_partition_destroy(libgamma_partition_state_t* restrict this)
{
}
@@ -107,7 +107,7 @@ void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this)
*
* @param this The partition state
*/
-void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this)
+void libgamma_x_vidmode_partition_free(libgamma_partition_state_t* restrict this)
{
}
@@ -119,7 +119,7 @@ void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this)
+int libgamma_x_vidmode_partition_restore(libgamma_partition_state_t* restrict this)
{
}
@@ -134,8 +134,8 @@ int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
- libgamma_partition_state_t* restrict partition, size_t crtc)
+int libgamma_x_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+ libgamma_partition_state_t* restrict partition, size_t crtc)
{
}
@@ -145,7 +145,7 @@ int libgamma_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this)
+void libgamma_x_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this)
{
}
@@ -156,7 +156,7 @@ void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this)
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this)
+void libgamma_x_vidmode_crtc_free(libgamma_crtc_state_t* restrict this)
{
}
@@ -168,7 +168,7 @@ void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this)
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this)
+int libgamma_x_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this)
{
}
@@ -182,8 +182,8 @@ int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this)
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
- libgamma_crtc_state_t* restrict crtc, int32_t fields)
+int libgamma_x_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+ libgamma_crtc_state_t* restrict crtc, int32_t fields)
{
}
@@ -196,8 +196,8 @@ int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict th
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t* restrict ramps)
+int libgamma_x_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t* restrict ramps)
{
}
@@ -210,8 +210,8 @@ int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t ramps)
+int libgamma_x_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t ramps)
{
}
@@ -225,8 +225,8 @@ int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t* restrict ramps)
+int libgamma_x_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t* restrict ramps)
{
}
@@ -239,8 +239,8 @@ int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t ramps)
+int libgamma_x_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t ramps)
{
}
@@ -254,8 +254,8 @@ int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t* restrict ramps)
+int libgamma_x_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t* restrict ramps)
{
}
@@ -268,8 +268,8 @@ int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t ramps)
+int libgamma_x_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t ramps)
{
}
@@ -283,8 +283,8 @@ int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t* restrict ramps)
+int libgamma_x_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t* restrict ramps)
{
}
@@ -297,8 +297,8 @@ int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t ramps)
+int libgamma_x_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t ramps)
{
}
@@ -311,8 +311,8 @@ int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t* restrict ramps)
+int libgamma_x_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t* restrict ramps)
{
}
@@ -325,8 +325,8 @@ int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t ramps)
+int libgamma_x_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t ramps)
{
}
@@ -15,11 +15,11 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef HAVE_GAMMA_METHOD_RANDR
-# error Compiling gamma-randr.c without HAVE_GAMMA_METHOD_RANDR
+#ifndef HAVE_GAMMA_METHOD_X_VIDMODE
+# error Compiling gamma-x-vidmode.c without HAVE_GAMMA_METHOD_X_VIDMODE
#endif
diff --git a/src/gamma-randr.h b/src/gamma-x-vidmode.h
index 7d0ba9e..670e06d 100644
--- a/src/gamma-randr.h
+++ b/src/gamma-x-vidmode.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LIBGAMMA_GAMMA_RANDR_H
#define LIBGAMMA_GAMMA_RANDR_H
#ifndef HAVE_GAMMA_METHOD_RANDR
# error Including gamma-randr.h without HAVE_GAMMA_METHOD_RANDR
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_x_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,15 +47,15 @@ void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_initialise(libgamma_site_state_t* restrict this,
- char* restrict site);
+int libgamma_x_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+ char* restrict site);
/**
* Release all resources held by a site state
*
* @param this The site state
*/
-void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_x_vidmode_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_x_vidmode_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,15 +76,15 @@ int libgamma_randr_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_initialise(libgamma_partition_state_t* restrict this,
- libgamma_site_state_t* restrict site, size_t partition);
+int libgamma_x_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+ libgamma_site_state_t* restrict site, size_t partition);
/**
* Release all resources held by a partition state
*
* @param this The partition state
*/
-void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_x_vidmode_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this)
*
* @param this The partition state
*/
-void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_x_vidmode_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_x_vidmode_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,15 +113,15 @@ int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
- libgamma_partition_state_t* restrict partition, size_t crtc);
+int libgamma_x_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+ libgamma_partition_state_t* restrict partition, size_t crtc);
/**
* Release all resources held by a CRTC state
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_x_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_x_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_x_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,8 +149,8 @@ int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
- libgamma_crtc_state_t* restrict crtc, int32_t fields);
+int libgamma_x_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+ libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
* Get current the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -160,8 +160,8 @@ int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict th
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -171,8 +171,8 @@ int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t ramps);
/**
@@ -183,8 +183,8 @@ int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 32-bit gamma-depth version
@@ -194,8 +194,8 @@ int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t ramps);
/**
@@ -206,8 +206,8 @@ int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 64-bit gamma-depth version
@@ -217,8 +217,8 @@ int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t ramps);
/**
@@ -229,8 +229,8 @@ int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `float` version
@@ -240,8 +240,8 @@ int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t ramps);
/**
* Get current the gamma ramps for a CRTC, `double` version
@@ -251,8 +251,8 @@ int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `double` version
@@ -262,8 +262,8 @@ int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t ramps);
#endif
@@ -15,12 +15,12 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_RANDR_H
-#define LIBGAMMA_GAMMA_RANDR_H
+#ifndef LIBGAMMA_GAMMA_X_VIDMODE_H
+#define LIBGAMMA_GAMMA_X_VIDMODE_H
-#ifndef HAVE_GAMMA_METHOD_RANDR
-# error Including gamma-randr.h without HAVE_GAMMA_METHOD_RANDR
+#ifndef HAVE_GAMMA_METHOD_X_VIDMODE
+# error Including gamma-x-vidmode.h without HAVE_GAMMA_METHOD_X_VIDMODE
#endif